==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/KeystoneIdentityProviderFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface KeystoneIdentityProviderFluent<A extends io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildCa instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.ConfigMapNameReference getCa();
  public io.fabric8.openshift.api.model.ConfigMapNameReference buildCa();
  public A withCa(io.fabric8.openshift.api.model.ConfigMapNameReference ca);
  public java.lang.Boolean hasCa();
  public A withNewCa(java.lang.String name);
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.CaNested<A> withNewCa();
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.CaNested<A> withNewCaLike(io.fabric8.openshift.api.model.ConfigMapNameReference item);
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.CaNested<A> editCa();
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.CaNested<A> editOrNewCa();
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.CaNested<A> editOrNewCaLike(io.fabric8.openshift.api.model.ConfigMapNameReference item);
  public java.lang.String getDomainName();
  public A withDomainName(java.lang.String domainName);
  public java.lang.Boolean hasDomainName();
  
  /**
   * Method is deprecated. use withDomainName instead.
   */
  @java.lang.Deprecated
  public A withNewDomainName(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildTlsClientCert instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.SecretNameReference getTlsClientCert();
  public io.fabric8.openshift.api.model.SecretNameReference buildTlsClientCert();
  public A withTlsClientCert(io.fabric8.openshift.api.model.SecretNameReference tlsClientCert);
  public java.lang.Boolean hasTlsClientCert();
  public A withNewTlsClientCert(java.lang.String name);
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientCertNested<A> withNewTlsClientCert();
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientCertNested<A> withNewTlsClientCertLike(io.fabric8.openshift.api.model.SecretNameReference item);
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientCertNested<A> editTlsClientCert();
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientCertNested<A> editOrNewTlsClientCert();
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientCertNested<A> editOrNewTlsClientCertLike(io.fabric8.openshift.api.model.SecretNameReference item);
  
  /**
   * This method has been deprecated, please use method buildTlsClientKey instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.SecretNameReference getTlsClientKey();
  public io.fabric8.openshift.api.model.SecretNameReference buildTlsClientKey();
  public A withTlsClientKey(io.fabric8.openshift.api.model.SecretNameReference tlsClientKey);
  public java.lang.Boolean hasTlsClientKey();
  public A withNewTlsClientKey(java.lang.String name);
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientKeyNested<A> withNewTlsClientKey();
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientKeyNested<A> withNewTlsClientKeyLike(io.fabric8.openshift.api.model.SecretNameReference item);
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientKeyNested<A> editTlsClientKey();
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientKeyNested<A> editOrNewTlsClientKey();
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientKeyNested<A> editOrNewTlsClientKeyLike(io.fabric8.openshift.api.model.SecretNameReference item);
  public java.lang.String getUrl();
  public A withUrl(java.lang.String url);
  public java.lang.Boolean hasUrl();
  
  /**
   * Method is deprecated. use withUrl instead.
   */
  @java.lang.Deprecated
  public A withNewUrl(java.lang.String arg0);
  public interface CaNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.ConfigMapNameReferenceFluent<io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.CaNested<N>>{
    public N and();
    public N endCa();
    
  }
  public interface TlsClientCertNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.SecretNameReferenceFluent<io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientCertNested<N>>{
    public N and();
    public N endTlsClientCert();
    
  }
  public interface TlsClientKeyNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.SecretNameReferenceFluent<io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientKeyNested<N>>{
    public N and();
    public N endTlsClientKey();
    
  }
  
}

==> openshift-model-5.12.1-sources.jar: io/fabric8/openshift/api/model/KeystoneIdentityProviderFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface KeystoneIdentityProviderFluent<A extends io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildCa instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.ConfigMapNameReference getCa();
  public io.fabric8.openshift.api.model.ConfigMapNameReference buildCa();
  public A withCa(io.fabric8.openshift.api.model.ConfigMapNameReference ca);
  public java.lang.Boolean hasCa();
  public A withNewCa(java.lang.String name);
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.CaNested<A> withNewCa();
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.CaNested<A> withNewCaLike(io.fabric8.openshift.api.model.ConfigMapNameReference item);
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.CaNested<A> editCa();
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.CaNested<A> editOrNewCa();
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.CaNested<A> editOrNewCaLike(io.fabric8.openshift.api.model.ConfigMapNameReference item);
  public java.lang.String getDomainName();
  public A withDomainName(java.lang.String domainName);
  public java.lang.Boolean hasDomainName();
  
  /**
   * Method is deprecated. use withDomainName instead.
   */
  @java.lang.Deprecated
  public A withNewDomainName(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildTlsClientCert instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.SecretNameReference getTlsClientCert();
  public io.fabric8.openshift.api.model.SecretNameReference buildTlsClientCert();
  public A withTlsClientCert(io.fabric8.openshift.api.model.SecretNameReference tlsClientCert);
  public java.lang.Boolean hasTlsClientCert();
  public A withNewTlsClientCert(java.lang.String name);
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientCertNested<A> withNewTlsClientCert();
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientCertNested<A> withNewTlsClientCertLike(io.fabric8.openshift.api.model.SecretNameReference item);
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientCertNested<A> editTlsClientCert();
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientCertNested<A> editOrNewTlsClientCert();
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientCertNested<A> editOrNewTlsClientCertLike(io.fabric8.openshift.api.model.SecretNameReference item);
  
  /**
   * This method has been deprecated, please use method buildTlsClientKey instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.SecretNameReference getTlsClientKey();
  public io.fabric8.openshift.api.model.SecretNameReference buildTlsClientKey();
  public A withTlsClientKey(io.fabric8.openshift.api.model.SecretNameReference tlsClientKey);
  public java.lang.Boolean hasTlsClientKey();
  public A withNewTlsClientKey(java.lang.String name);
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientKeyNested<A> withNewTlsClientKey();
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientKeyNested<A> withNewTlsClientKeyLike(io.fabric8.openshift.api.model.SecretNameReference item);
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientKeyNested<A> editTlsClientKey();
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientKeyNested<A> editOrNewTlsClientKey();
  public io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientKeyNested<A> editOrNewTlsClientKeyLike(io.fabric8.openshift.api.model.SecretNameReference item);
  public java.lang.String getUrl();
  public A withUrl(java.lang.String url);
  public java.lang.Boolean hasUrl();
  
  /**
   * Method is deprecated. use withUrl instead.
   */
  @java.lang.Deprecated
  public A withNewUrl(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface CaNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.ConfigMapNameReferenceFluent<io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.CaNested<N>>{
    public N and();
    public N endCa();
    
  }
  public interface TlsClientCertNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.SecretNameReferenceFluent<io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientCertNested<N>>{
    public N and();
    public N endTlsClientCert();
    
  }
  public interface TlsClientKeyNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.SecretNameReferenceFluent<io.fabric8.openshift.api.model.KeystoneIdentityProviderFluent.TlsClientKeyNested<N>>{
    public N and();
    public N endTlsClientKey();
    
  }
  
}
